@@ -227,6 +227,11 @@ void gdk_window_merge_child_shapes (GdkWindow *window);
 gboolean gdk_window_is_visible     (GdkWindow *window);
 gboolean gdk_window_is_viewable    (GdkWindow *window);
 
+/* Set static bit gravity on the parent, and static
+ * window gravity on all children.
+ */
+gboolean gdk_window_set_static_gravities (GdkWindow *window,
+					  gboolean   use_static);   
 /*
  * The following function adds a global filter for all client
  * messages of type message_type
@@ -257,8 +262,7 @@ GdkAtom          gdk_drag_get_selection (GdkDragContext   *context);
 /* Source side */
 
 GdkDragContext * gdk_drag_begin      (GdkWindow      *window,
-				      GList          *targets,
-				      GdkDragAction   actions);
+				      GList          *targets);
 guint32         gdk_drag_get_protocol (guint32          xid,
 				       GdkDragProtocol *protocol);
 void             gdk_drag_find_window (GdkDragContext   *context,
@@ -272,7 +276,8 @@ gboolean        gdk_drag_motion      (GdkDragContext *context,
 				      GdkDragProtocol protocol,
 				      gint            x_root, 
 				      gint            y_root,
-				      GdkDragAction   action,
+				      GdkDragAction   suggested_action,
+				      GdkDragAction   possible_actions,
 				      guint32         time);
 void            gdk_drag_drop        (GdkDragContext *context,
 				      guint32         time);
