@@ -36,14 +36,22 @@ extern "C" {
 typedef struct _GtkAccelGroup	GtkAccelGroup;
 typedef struct _GtkAccelEntry	GtkAccelEntry;
 
-/* enum GtkAccelFlags:
- *
- * GTK_ACCEL_VISIBLE		- should the accelerator appear in
- *				  the widget's display?
- * GTK_ACCEL_SIGNAL_VISIBLE	- should the signal associated
- *				  with this accelerator be also visible?
- * GTK_ACCEL_LOCKED		- may the accelerator be removed again?
- */
+typedef enum
+{
+  /* should the accelerator appear in
+   * the widget's display?
+   */
+  GTK_ACCEL_VISIBLE        = 1 << 0,
+  /* should the signal associated with
+   * this accelerator be also visible?
+   */
+  GTK_ACCEL_SIGNAL_VISIBLE = 1 << 1,
+  /* may the accelerator be removed
+   * again?
+   */
+  GTK_ACCEL_LOCKED         = 1 << 2,
+  GTK_ACCEL_MASK           = 0x07
+} GtkAccelFlags;
 
 struct _GtkAccelGroup
 {
