@@ -326,7 +326,7 @@ gtk_entry_get_arg (GtkObject      *object,
       GTK_VALUE_UINT (*arg) = entry->text_max_length;
       break;
     case ARG_VISIBILITY:
-      GTK_VALUE_BOOL (*arg) = entry->visible;
+      GTK_VALUE_BOOL (*arg) = GTK_EDITABLE (entry)->visible;
       break;
     default:
       arg->type = GTK_TYPE_INVALID;
@@ -460,7 +460,8 @@ gtk_entry_set_visibility (GtkEntry *entry,
   g_return_if_fail (entry != NULL);
   g_return_if_fail (GTK_IS_ENTRY (entry));
 
-  entry->visible = visible;
+  entry->visible = visible ? TRUE : FALSE;
+  GTK_EDITABLE (entry)->visible = visible ? TRUE : FALSE;
   gtk_entry_recompute_offsets (entry);
   gtk_widget_queue_draw (GTK_WIDGET (entry));
 }
@@ -538,6 +539,7 @@ gtk_entry_realize (GtkWidget *widget)
 {
   GtkEntry *entry;
   GtkEditable *editable;
+  GtkRequisition requisition;
   GdkWindowAttr attributes;
   gint attributes_mask;
 
@@ -547,13 +549,15 @@ gtk_entry_realize (GtkWidget *widget)
   GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
   entry = GTK_ENTRY (widget);
   editable = GTK_EDITABLE (widget);
+
+  gtk_widget_get_child_requisition (widget, &requisition);
   
   attributes.window_type = GDK_WINDOW_CHILD;
   attributes.x = widget->allocation.x;
   attributes.y = widget->allocation.y + (widget->allocation.height -
-					 widget->requisition.height) / 2;
+					 requisition.height) / 2;
   attributes.width = widget->allocation.width;
-  attributes.height = widget->requisition.height;
+  attributes.height = requisition.height;
   attributes.wclass = GDK_INPUT_OUTPUT;
   attributes.visual = gtk_widget_get_visual (widget);
   attributes.colormap = gtk_widget_get_colormap (widget);
@@ -575,7 +579,7 @@ gtk_entry_realize (GtkWidget *widget)
   attributes.x = widget->style->klass->xthickness;
   attributes.y = widget->style->klass->ythickness;
   attributes.width = widget->allocation.width - attributes.x * 2;
-  attributes.height = widget->requisition.height - attributes.y * 2;
+  attributes.height = requisition.height - attributes.y * 2;
   attributes.cursor = entry->cursor = gdk_cursor_new (GDK_XTERM);
   attributes_mask |= GDK_WA_CURSOR;
 
@@ -773,15 +777,22 @@ gtk_entry_size_allocate (GtkWidget     *widget,
 
   if (GTK_WIDGET_REALIZED (widget))
     {
+      /* We call gtk_widget_get_child_requisition, since we want (for
+       * backwards compatibility reasons) the realization here to
+       * be affected by the usize of the entry, if set
+       */
+      GtkRequisition requisition;
+      gtk_widget_get_child_requisition (widget, &requisition);
+  
       gdk_window_move_resize (widget->window,
 			      allocation->x,
-			      allocation->y + (allocation->height - widget->requisition.height) / 2,
-			      allocation->width, widget->requisition.height);
+			      allocation->y + (allocation->height - requisition.height) / 2,
+			      allocation->width, requisition.height);
       gdk_window_move_resize (entry->text_area,
 			      widget->style->klass->xthickness,
 			      widget->style->klass->ythickness,
 			      allocation->width - widget->style->klass->xthickness * 2,
-			      widget->requisition.height - widget->style->klass->ythickness * 2);
+			      requisition.height - widget->style->klass->ythickness * 2);
 
       /* And make sure the cursor is on screen */
       entry_adjust_scroll (entry);
@@ -1344,8 +1355,8 @@ gtk_entry_draw_text (GtkEntry *entry)
       selection_end_xoffset = 
 	entry->char_offset[selection_end_pos] -entry->scroll_offset;
 
-      /* if entry->visible, print a bunch of stars.  If not, print the standard text. */
-      if (entry->visible)
+      /* if editable->visible, print a bunch of stars.  If not, print the standard text. */
+      if (editable->visible)
 	{
 	  toprint = entry->text + start_pos;
 	}
@@ -1391,7 +1402,7 @@ gtk_entry_draw_text (GtkEntry *entry)
 			   toprint + selection_end_pos - start_pos,
 			   end_pos - selection_end_pos);
        /* free the space allocated for the stars if it's neccessary. */
-      if (!entry->visible)
+      if (!editable->visible)
 	g_free (toprint);
 
       if (editable->editable)
@@ -1725,7 +1736,7 @@ gtk_entry_insert_text (GtkEditable *editable,
       for (i=start_pos; i<end_pos; i++)
 	{
 	  entry->char_offset[i] = entry->char_offset[start_pos] + offset;
-	  if (entry->visible)
+	  if (editable->visible)
 	    {
 	      offset += gdk_char_width_wc (GTK_WIDGET (entry)->style->font,
 					   entry->text[i]);
@@ -1756,7 +1767,7 @@ gtk_entry_recompute_offsets (GtkEntry *entry)
   for (i=0; i<entry->text_length; i++)
     {
       entry->char_offset[i] = offset;
-      if (entry->visible)
+      if (GTK_EDITABLE (entry)->visible)
 	{
 	  offset += gdk_char_width_wc (GTK_WIDGET (entry)->style->font,
 				       entry->text[i]);
@@ -2252,9 +2263,6 @@ gtk_entry_style_set	(GtkWidget      *widget,
       gtk_entry_update_ic_attr (widget);
 #endif
     }
-
-  if (GTK_WIDGET_DRAWABLE (widget))
-    gtk_widget_queue_clear(widget);
 }
 
 static void
