@@ -326,11 +326,13 @@ gtk_list_size_request (GtkWidget      *widget,
 
       if (GTK_WIDGET_VISIBLE (child))
 	{
-	  gtk_widget_size_request (child, &child->requisition);
+	  GtkRequisition child_requisition;
+	  
+	  gtk_widget_size_request (child, &child_requisition);
 
 	  requisition->width = MAX (requisition->width,
-				    child->requisition.width);
-	  requisition->height += child->requisition.height;
+				    child_requisition.width);
+	  requisition->height += child_requisition.height;
 	}
     }
 
@@ -378,7 +380,10 @@ gtk_list_size_allocate (GtkWidget     *widget,
 
 	  if (GTK_WIDGET_VISIBLE (child))
 	    {
-	      child_allocation.height = child->requisition.height;
+	      GtkRequisition child_requisition;
+	      gtk_widget_get_child_requisition (child, &child_requisition);
+	      
+	      child_allocation.height = child_requisition.height;
 
 	      gtk_widget_size_allocate (child, &child_allocation);
 
@@ -1091,7 +1096,6 @@ gtk_list_insert_items (GtkList *list,
       gtk_signal_connect (GTK_OBJECT (widget), "toggle",
 			  GTK_SIGNAL_FUNC (gtk_list_signal_item_toggle),
 			  list);
-
       if (GTK_WIDGET_VISIBLE (widget->parent))
 	{
 	  if (GTK_WIDGET_REALIZED (widget->parent) &&
@@ -1104,6 +1108,7 @@ gtk_list_insert_items (GtkList *list,
 	}
     }
 
+
   nchildren = g_list_length (list->children);
   if ((position < 0) || (position > nchildren))
     position = nchildren;
@@ -1135,7 +1140,7 @@ gtk_list_insert_items (GtkList *list,
       if (tmp_list == list->children)
 	list->children = items;
     }
-
+  
   if (list->children && !list->selection &&
       (list->selection_mode == GTK_SELECTION_BROWSE))
     {
@@ -1406,8 +1411,7 @@ gtk_list_remove_items_internal (GtkList	 *list,
       else if (container->focus_child)
 	gtk_container_set_focus_child (container, new_focus_child);
 
-      if ((list->selection_mode == GTK_SELECTION_BROWSE ||
-	   list->selection_mode == GTK_SELECTION_EXTENDED) && !list->selection)
+      if (list->selection_mode == GTK_SELECTION_BROWSE && !list->selection)
 	{
 	  list->last_focus_child = new_focus_child; 
 	  gtk_list_select_child (list, new_focus_child);
@@ -1572,7 +1576,7 @@ gtk_list_unselect_all (GtkList *list)
 
   if (!list->children)
     return;
-  
+
   if (gdk_pointer_is_grabbed () && GTK_WIDGET_HAS_GRAB (list))
     gtk_list_end_drag_selection (list);
 
