@@ -100,6 +100,7 @@ gtk_list_item_class_init (GtkListItemClass *class)
   GtkObjectClass *object_class;
   GtkWidgetClass *widget_class;
   GtkItemClass *item_class;
+  GtkBindingSet *binding_set;
 
   object_class = (GtkObjectClass*) class;
   widget_class = (GtkWidgetClass*) class;
@@ -207,103 +208,97 @@ gtk_list_item_class_init (GtkListItemClass *class)
   class->scroll_vertical = NULL;
   class->toggle_add_mode = NULL;
 
-  {
-    GtkBindingSet *binding_set;
 
-    binding_set = gtk_binding_set_by_class (class);
-    gtk_binding_entry_add_signal (binding_set, GDK_Up, 0,
-				  "scroll_vertical", 2,
-				  GTK_TYPE_ENUM, GTK_SCROLL_STEP_BACKWARD,
-                                  GTK_TYPE_FLOAT, 0.0);
-    gtk_binding_entry_add_signal (binding_set, GDK_Down, 0,
-				  "scroll_vertical", 2,
-				  GTK_TYPE_ENUM, GTK_SCROLL_STEP_FORWARD,
-                                  GTK_TYPE_FLOAT, 0.0);
-    gtk_binding_entry_add_signal (binding_set, GDK_Page_Up, 0,
-				  "scroll_vertical", 2,
-				  GTK_TYPE_ENUM, GTK_SCROLL_PAGE_BACKWARD,
-                                  GTK_TYPE_FLOAT, 0.0);
-    gtk_binding_entry_add_signal (binding_set, GDK_Page_Down, 0,
-				  "scroll_vertical", 2,
-				  GTK_TYPE_ENUM, GTK_SCROLL_PAGE_FORWARD,
-                                  GTK_TYPE_FLOAT, 0.0);
-    gtk_binding_entry_add_signal (binding_set, GDK_Home, GDK_CONTROL_MASK,
-				  "scroll_vertical", 2,
-				  GTK_TYPE_ENUM, GTK_SCROLL_JUMP,
-                                  GTK_TYPE_FLOAT, 0.0);
-    gtk_binding_entry_add_signal (binding_set, GDK_End, GDK_CONTROL_MASK,
-				  "scroll_vertical", 2,
-				  GTK_TYPE_ENUM, GTK_SCROLL_JUMP,
-                                  GTK_TYPE_FLOAT, 1.0);
+  binding_set = gtk_binding_set_by_class (class);
+  gtk_binding_entry_add_signal (binding_set, GDK_Up, 0,
+				"scroll_vertical", 2,
+				GTK_TYPE_ENUM, GTK_SCROLL_STEP_BACKWARD,
+				GTK_TYPE_FLOAT, 0.0);
+  gtk_binding_entry_add_signal (binding_set, GDK_Down, 0,
+				"scroll_vertical", 2,
+				GTK_TYPE_ENUM, GTK_SCROLL_STEP_FORWARD,
+				GTK_TYPE_FLOAT, 0.0);
+  gtk_binding_entry_add_signal (binding_set, GDK_Page_Up, 0,
+				"scroll_vertical", 2,
+				GTK_TYPE_ENUM, GTK_SCROLL_PAGE_BACKWARD,
+				GTK_TYPE_FLOAT, 0.0);
+  gtk_binding_entry_add_signal (binding_set, GDK_Page_Down, 0,
+				"scroll_vertical", 2,
+				GTK_TYPE_ENUM, GTK_SCROLL_PAGE_FORWARD,
+				GTK_TYPE_FLOAT, 0.0);
+  gtk_binding_entry_add_signal (binding_set, GDK_Home, GDK_CONTROL_MASK,
+				"scroll_vertical", 2,
+				GTK_TYPE_ENUM, GTK_SCROLL_JUMP,
+				GTK_TYPE_FLOAT, 0.0);
+  gtk_binding_entry_add_signal (binding_set, GDK_End, GDK_CONTROL_MASK,
+				"scroll_vertical", 2,
+				GTK_TYPE_ENUM, GTK_SCROLL_JUMP,
+				GTK_TYPE_FLOAT, 1.0);
 
-    gtk_binding_entry_add_signal (binding_set, GDK_Up, GDK_SHIFT_MASK,
-				  "extend_selection", 3,
-				  GTK_TYPE_ENUM, GTK_SCROLL_STEP_BACKWARD,
-                                  GTK_TYPE_FLOAT, 0.0, GTK_TYPE_BOOL, TRUE);
-    gtk_binding_entry_add_signal (binding_set, GDK_Down, GDK_SHIFT_MASK,
-				  "extend_selection", 3,
-				  GTK_TYPE_ENUM, GTK_SCROLL_STEP_FORWARD,
-                                  GTK_TYPE_FLOAT, 0.0, GTK_TYPE_BOOL, TRUE);
-    gtk_binding_entry_add_signal (binding_set, GDK_Page_Up, GDK_SHIFT_MASK,
-				  "extend_selection", 3,
-				  GTK_TYPE_ENUM, GTK_SCROLL_PAGE_BACKWARD,
-                                  GTK_TYPE_FLOAT, 0.0, GTK_TYPE_BOOL, TRUE);
-    gtk_binding_entry_add_signal (binding_set, GDK_Page_Down, GDK_SHIFT_MASK,
-				  "extend_selection", 3,
-				  GTK_TYPE_ENUM, GTK_SCROLL_PAGE_FORWARD,
-                                  GTK_TYPE_FLOAT, 0.0, GTK_TYPE_BOOL, TRUE);
-    gtk_binding_entry_add_signal (binding_set, GDK_Home,
-				  GDK_SHIFT_MASK | GDK_CONTROL_MASK,
-				  "extend_selection", 3,
-				  GTK_TYPE_ENUM, GTK_SCROLL_JUMP,
-                                  GTK_TYPE_FLOAT, 0.0, GTK_TYPE_BOOL, TRUE);
-    gtk_binding_entry_add_signal (binding_set, GDK_End,
-				  GDK_SHIFT_MASK | GDK_CONTROL_MASK,
-				  "extend_selection", 3,
-				  GTK_TYPE_ENUM, GTK_SCROLL_JUMP,
-                                  GTK_TYPE_FLOAT, 1.0, GTK_TYPE_BOOL, TRUE);
+  gtk_binding_entry_add_signal (binding_set, GDK_Up, GDK_SHIFT_MASK,
+				"extend_selection", 3,
+				GTK_TYPE_ENUM, GTK_SCROLL_STEP_BACKWARD,
+				GTK_TYPE_FLOAT, 0.0, GTK_TYPE_BOOL, TRUE);
+  gtk_binding_entry_add_signal (binding_set, GDK_Down, GDK_SHIFT_MASK,
+				"extend_selection", 3,
+				GTK_TYPE_ENUM, GTK_SCROLL_STEP_FORWARD,
+				GTK_TYPE_FLOAT, 0.0, GTK_TYPE_BOOL, TRUE);
+  gtk_binding_entry_add_signal (binding_set, GDK_Page_Up, GDK_SHIFT_MASK,
+				"extend_selection", 3,
+				GTK_TYPE_ENUM, GTK_SCROLL_PAGE_BACKWARD,
+				GTK_TYPE_FLOAT, 0.0, GTK_TYPE_BOOL, TRUE);
+  gtk_binding_entry_add_signal (binding_set, GDK_Page_Down, GDK_SHIFT_MASK,
+				"extend_selection", 3,
+				GTK_TYPE_ENUM, GTK_SCROLL_PAGE_FORWARD,
+				GTK_TYPE_FLOAT, 0.0, GTK_TYPE_BOOL, TRUE);
+  gtk_binding_entry_add_signal (binding_set, GDK_Home,
+				GDK_SHIFT_MASK | GDK_CONTROL_MASK,
+				"extend_selection", 3,
+				GTK_TYPE_ENUM, GTK_SCROLL_JUMP,
+				GTK_TYPE_FLOAT, 0.0, GTK_TYPE_BOOL, TRUE);
+  gtk_binding_entry_add_signal (binding_set, GDK_End,
+				GDK_SHIFT_MASK | GDK_CONTROL_MASK,
+				"extend_selection", 3,
+				GTK_TYPE_ENUM, GTK_SCROLL_JUMP,
+				GTK_TYPE_FLOAT, 1.0, GTK_TYPE_BOOL, TRUE);
 
+  gtk_binding_entry_add_signal (binding_set, GDK_Left, 0,
+				"scroll_horizontal", 2,
+				GTK_TYPE_ENUM, GTK_SCROLL_STEP_BACKWARD,
+				GTK_TYPE_FLOAT, 0.0);
+  gtk_binding_entry_add_signal (binding_set, GDK_Right, 0,
+				"scroll_horizontal", 2,
+				GTK_TYPE_ENUM, GTK_SCROLL_STEP_FORWARD,
+				GTK_TYPE_FLOAT, 0.0);
+  gtk_binding_entry_add_signal (binding_set, GDK_Home, 0,
+				"scroll_horizontal", 2,
+				GTK_TYPE_ENUM, GTK_SCROLL_JUMP,
+				GTK_TYPE_FLOAT, 0.0);
+  gtk_binding_entry_add_signal (binding_set, GDK_End, 0,
+				"scroll_horizontal", 2,
+				GTK_TYPE_ENUM, GTK_SCROLL_JUMP,
+				GTK_TYPE_FLOAT, 1.0);
 
-    gtk_binding_entry_add_signal (binding_set, GDK_Left, 0,
-				  "scroll_horizontal", 2,
-				  GTK_TYPE_ENUM, GTK_SCROLL_STEP_BACKWARD,
-                                  GTK_TYPE_FLOAT, 0.0);
-    gtk_binding_entry_add_signal (binding_set, GDK_Right, 0,
-				  "scroll_horizontal", 2,
-				  GTK_TYPE_ENUM, GTK_SCROLL_STEP_FORWARD,
-                                  GTK_TYPE_FLOAT, 0.0);
-    gtk_binding_entry_add_signal (binding_set, GDK_Home, 0,
-				  "scroll_horizontal", 2,
-				  GTK_TYPE_ENUM, GTK_SCROLL_JUMP,
-                                  GTK_TYPE_FLOAT, 0.0);
-    gtk_binding_entry_add_signal (binding_set, GDK_End, 0,
-				  "scroll_horizontal", 2,
-				  GTK_TYPE_ENUM, GTK_SCROLL_JUMP,
-                                  GTK_TYPE_FLOAT, 1.0);
-
-
-    gtk_binding_entry_add_signal (binding_set, GDK_Escape, 0,
-				  "undo_selection", 0);
-    gtk_binding_entry_add_signal (binding_set, GDK_space, 0,
-				  "toggle_focus_row", 0);
-    gtk_binding_entry_add_signal (binding_set, GDK_space, GDK_CONTROL_MASK,
-				  "toggle_add_mode", 0);
-    gtk_binding_entry_add_signal (binding_set, '/', GDK_CONTROL_MASK,
-				  "select_all", 0);
-    gtk_binding_entry_add_signal (binding_set, '\\', GDK_CONTROL_MASK,
-				  "unselect_all", 0);
-    gtk_binding_entry_add_signal (binding_set, GDK_Shift_L,
-				  GDK_RELEASE_MASK | GDK_SHIFT_MASK,
-				  "end_selection", 0);
-    gtk_binding_entry_add_signal (binding_set, GDK_Shift_R,
-				  GDK_RELEASE_MASK | GDK_SHIFT_MASK,
-				  "end_selection", 0);
-    gtk_binding_entry_add_signal (binding_set, GDK_Shift_R,
-				  GDK_RELEASE_MASK | GDK_SHIFT_MASK |
-				  GDK_CONTROL_MASK,
-				  "end_selection", 0);
-  }
-
+  gtk_binding_entry_add_signal (binding_set, GDK_Escape, 0,
+				"undo_selection", 0);
+  gtk_binding_entry_add_signal (binding_set, GDK_space, 0,
+				"toggle_focus_row", 0);
+  gtk_binding_entry_add_signal (binding_set, GDK_space, GDK_CONTROL_MASK,
+				"toggle_add_mode", 0);
+  gtk_binding_entry_add_signal (binding_set, '/', GDK_CONTROL_MASK,
+				"select_all", 0);
+  gtk_binding_entry_add_signal (binding_set, '\\', GDK_CONTROL_MASK,
+				"unselect_all", 0);
+  gtk_binding_entry_add_signal (binding_set, GDK_Shift_L,
+				GDK_RELEASE_MASK | GDK_SHIFT_MASK,
+				"end_selection", 0);
+  gtk_binding_entry_add_signal (binding_set, GDK_Shift_R,
+				GDK_RELEASE_MASK | GDK_SHIFT_MASK,
+				"end_selection", 0);
+  gtk_binding_entry_add_signal (binding_set, GDK_Shift_R,
+				GDK_RELEASE_MASK | GDK_SHIFT_MASK |
+				GDK_CONTROL_MASK,
+				"end_selection", 0);
 }
 
 static void
@@ -392,6 +387,7 @@ gtk_list_item_size_request (GtkWidget      *widget,
 			    GtkRequisition *requisition)
 {
   GtkBin *bin;
+  GtkRequisition child_requisition;
 
   g_return_if_fail (widget != NULL);
   g_return_if_fail (GTK_IS_LIST_ITEM (widget));
@@ -405,10 +401,10 @@ gtk_list_item_size_request (GtkWidget      *widget,
 
   if (bin->child && GTK_WIDGET_VISIBLE (bin->child))
     {
-      gtk_widget_size_request (bin->child, &bin->child->requisition);
+      gtk_widget_size_request (bin->child, &child_requisition);
 
-      requisition->width += bin->child->requisition.width;
-      requisition->height += bin->child->requisition.height;
+      requisition->width += child_requisition.width;
+      requisition->height += child_requisition.height;
     }
 }
 
