@@ -352,54 +352,6 @@ gtk_object_class_add_signals (GtkObjectClass *class,
   class->nsignals += nsignals;
 }
 
-guint
-gtk_object_class_add_user_signal (GtkObjectClass     *class,
-				  const gchar        *name,
-				  GtkSignalMarshaller marshaller,
-				  GtkType             return_val,
-				  guint               nparams,
-				  ...)
-{
-  GtkType *params;
-  guint i;
-  va_list args;
-  guint signal_id;
-
-  g_return_val_if_fail (class != NULL, 0);
-
-  g_message ("gtk_object_class_add_user_signal() is deprecated");
-
-  if (nparams > 0)
-    {
-      params = g_new (GtkType, nparams);
-
-      va_start (args, nparams);
-
-      for (i = 0; i < nparams; i++)
-	params[i] = va_arg (args, GtkType);
-
-      va_end (args);
-    }
-  else
-    params = NULL;
-
-  signal_id = gtk_signal_newv (name,
-			       0,
-			       class->type,
-			       0,
-			       marshaller,
-			       return_val,
-			       nparams,
-			       params);
-
-  g_free (params);
-
-  if (signal_id)
-    gtk_object_class_add_signals (class, &signal_id, 1);
-
-  return signal_id;
-}
-
 guint
 gtk_object_class_user_signal_new (GtkObjectClass     *class,
 				  const gchar        *name,
