@@ -249,11 +249,6 @@ gtk_ruler_expose (GtkWidget      *widget,
     {
       ruler = GTK_RULER (widget);
 
-      gtk_paint_box (widget->style, widget->window,
-		     GTK_STATE_NORMAL, GTK_SHADOW_OUT, 
-		     NULL, widget, "ruler",
-		     0, 0, -1, -1);
-      
       gtk_ruler_draw_ticks (ruler);
       
       gdk_draw_pixmap (widget->window,
