@@ -33,23 +33,26 @@ typedef struct _GtkStyleClass  GtkStyleClass;
 /* Some forward declarations needed to rationalize the header
  * files.
  */
-
 typedef struct _GtkThemeEngine GtkThemeEngine;
 typedef struct _GtkRcStyle     GtkRcStyle;
 
+
 /* We make this forward declaration here, since we pass
  * GtkWidgt's to the draw functions.
  */
 typedef struct _GtkWidget      GtkWidget;
 
-/* This is used for having dynamic style changing stuff */
-/* fg, bg, light, dark, mid, text, base */
-#define GTK_STYLE_NUM_STYLECOLORS() 7*5
+/* This is used for having dynamic style changing stuff
+ * fg, bg, light, dark, mid, text, base
+ */
+#define GTK_STYLE_NUM_STYLECOLORS()	(7 * 5)
 
-#define	GTK_STYLE_ATTACHED(style)	(((GtkStyle*)(style))->attach_count > 0)
+#define GTK_STYLE_ATTACHED(style)	(((GtkStyle*) (style))->attach_count > 0)
 
 struct _GtkStyle
 {
+  GtkStyleClass *klass;
+
   GdkColor fg[5];
   GdkColor bg[5];
   GdkColor light[5];
@@ -57,11 +60,11 @@ struct _GtkStyle
   GdkColor mid[5];
   GdkColor text[5];
   GdkColor base[5];
-
+  
   GdkColor black;
   GdkColor white;
   GdkFont *font;
-
+  
   GdkGC *fg_gc[5];
   GdkGC *bg_gc[5];
   GdkGC *light_gc[5];
@@ -71,286 +74,288 @@ struct _GtkStyle
   GdkGC *base_gc[5];
   GdkGC *black_gc;
   GdkGC *white_gc;
-
+  
   GdkPixmap *bg_pixmap[5];
-
-  /* Private */
+  
+  /* private */
+  
   gint ref_count;
   gint attach_count;
-
+  
   gint depth;
   GdkColormap *colormap;
-
-  GtkStyleClass  *klass;        /* Not private - reorder me */
+  
   GtkThemeEngine *engine;
-
-  gpointer        engine_data;
-
-  GtkRcStyle     *rc_style;	/* the Rc style from which this style
-				 * was created */
-  GSList         *styles;
+  
+  gpointer	  engine_data;
+  
+  GtkRcStyle	 *rc_style;	/* the Rc style from which this style
+				 * was created
+				 */
+  GSList	 *styles;
 };
 
 struct _GtkStyleClass
 {
   gint xthickness;
   gint ythickness;
-
-  void (*draw_hline)   (GtkStyle      *style,
-			GdkWindow     *window,
-			GtkStateType   state_type,
-			GdkRectangle  *area,
-			GtkWidget     *widget,
-			gchar         *detail,
-			gint	       x1,
-			gint	       x2,
-			gint	       y);
-  void (*draw_vline)   (GtkStyle      *style,
-			GdkWindow     *window,
-			GtkStateType   state_type,
-			GdkRectangle  *area,
-			GtkWidget     *widget,
-			gchar         *detail,
-			gint	       y1,
-			gint	       y2,
-			gint	       x);
-  void (*draw_shadow)  (GtkStyle      *style,
-			GdkWindow     *window,
-			GtkStateType   state_type,
-			GtkShadowType  shadow_type,
-			GdkRectangle  *area,
-			GtkWidget     *widget,
-			gchar         *detail,
-			gint	       x,
-			gint	       y,
-			gint	       width,
-			gint	       height);
-  void (*draw_polygon) (GtkStyle      *style,
-			GdkWindow     *window,
-			GtkStateType   state_type,
-			GtkShadowType  shadow_type,
-			GdkRectangle  *area,
-			GtkWidget     *widget,
-			gchar         *detail,
-			GdkPoint      *point,
-			gint	       npoints,
-			gboolean       fill);
-  void (*draw_arrow)   (GtkStyle      *style,
-			GdkWindow     *window,
-			GtkStateType   state_type,
-			GtkShadowType  shadow_type,
-			GdkRectangle  *area,
-			GtkWidget     *widget,
-			gchar         *detail,
-			GtkArrowType   arrow_type,
-			gboolean       fill,
-			gint	       x,
-			gint	       y,
-			gint	       width,
-			gint	       height);
-  void (*draw_diamond) (GtkStyle      *style,
-			GdkWindow     *window,
-			GtkStateType   state_type,
-			GtkShadowType  shadow_type,
-			GdkRectangle  *area,
-			GtkWidget     *widget,
-			gchar         *detail,
-			gint	       x,
-			gint	       y,
-			gint	       width,
-			gint	       height);
-  void (*draw_oval)    (GtkStyle      *style,
-			GdkWindow     *window,
-			GtkStateType   state_type,
-			GtkShadowType  shadow_type,
-			GdkRectangle  *area,
-			GtkWidget     *widget,
-			gchar         *detail,
-			gint	       x,
-			gint	       y,
-			gint	       width,
-			gint	       height);
-  void (*draw_string)  (GtkStyle      *style,
-			GdkWindow     *window,
-			GtkStateType   state_type,
-			GdkRectangle  *area,
-			GtkWidget     *widget,
-			gchar         *detail,
-			gint	       x,
-			gint	       y,
-			const gchar   *string);
-  void (*draw_box)     (GtkStyle      *style,
-			GdkWindow     *window,
-			GtkStateType   state_type,
-			GtkShadowType  shadow_type,
-			GdkRectangle  *area,
-			GtkWidget     *widget,
-			gchar         *detail,
-			gint           x,
-			gint           y,
-			gint           width,
-			gint           height);
-  void (*draw_flat_box) (GtkStyle      *style,
-			GdkWindow     *window,
-			GtkStateType   state_type,
-			GtkShadowType  shadow_type,
-			GdkRectangle  *area,
-			GtkWidget     *widget,
-			gchar         *detail,
-			gint           x,
-			gint           y,
-			gint           width,
-			gint           height);
-  void (*draw_check)   (GtkStyle      *style,
-			GdkWindow     *window,
-			GtkStateType   state_type,
-			GtkShadowType  shadow_type,
-			GdkRectangle  *area,
-			GtkWidget     *widget,
-			gchar         *detail,
-			gint           x,
-			gint           y,
-			gint           width,
-			gint           height);
-  void (*draw_option)  (GtkStyle      *style,
-			GdkWindow     *window,
-			GtkStateType   state_type,
-			GtkShadowType  shadow_type,
-			GdkRectangle  *area,
-			GtkWidget     *widget,
-			gchar         *detail,
-			gint           x,
-			gint           y,
-			gint           width,
-			gint           height);
-  void (*draw_cross)   (GtkStyle      *style,
-			GdkWindow     *window,
-			GtkStateType   state_type,
-			GtkShadowType  shadow_type,
-			GdkRectangle  *area,
-			GtkWidget     *widget,
-			gchar         *detail,
-			gint           x,
-			gint           y,
-			gint           width,
-			gint           height);
-  void (*draw_ramp)    (GtkStyle      *style,
-			GdkWindow     *window,
-			GtkStateType   state_type,
-			GtkShadowType  shadow_type,
-			GdkRectangle  *area,
-			GtkWidget     *widget,
-			gchar         *detail,
-			GtkArrowType   arrow_type,
-			gint	       x,
-			gint	       y,
-			gint	       width,
-			gint	       height);
-  void (*draw_tab)     (GtkStyle      *style,
-			GdkWindow     *window,
-			GtkStateType   state_type,
-			GtkShadowType  shadow_type,
-			GdkRectangle  *area,
-			GtkWidget     *widget,
-			gchar         *detail,
-			gint	       x,
-			gint	       y,
-			gint	       width,
-			gint	       height); 
-  void (*draw_shadow_gap) (GtkStyle       *style,
-			   GdkWindow      *window,
-			   GtkStateType    state_type,
-			   GtkShadowType   shadow_type,
-			   GdkRectangle   *area,
-			   GtkWidget      *widget,
-			   gchar          *detail,
-			   gint	           x,
-			   gint	           y,
-			   gint	           width,
-			   gint	           height,
-			   GtkPositionType gap_side,
-			   gint            gap_x,
-			   gint            gap_width);
-  void (*draw_box_gap) (GtkStyle       *style,
-			GdkWindow      *window,
-			GtkStateType    state_type,
-			GtkShadowType   shadow_type,
-			GdkRectangle   *area,
-			GtkWidget      *widget,
-			gchar          *detail,
-			gint	        x,
-			gint	        y,
-			gint	        width,
-			gint	        height,
-			GtkPositionType gap_side,
-			gint            gap_x,
-		        gint            gap_width);
- void (*draw_extension) (GtkStyle       *style,
-			 GdkWindow      *window,
-			 GtkStateType    state_type,
-			 GtkShadowType   shadow_type,
-			 GdkRectangle   *area,
-			 GtkWidget      *widget,
-			 gchar          *detail,
-			 gint	         x,
-			 gint	         y,
-			 gint	         width,
-			 gint	         height,
-			 GtkPositionType gap_side);
-   void (*draw_focus) (GtkStyle      *style,
-		       GdkWindow     *window,
-		       GdkRectangle  *area,
-		       GtkWidget     *widget,
-		       gchar         *detail,
-		       gint           x,
-		       gint           y,
-		       gint           width,
-		       gint           height);
-   void (*draw_slider)  (GtkStyle      *style,
-			 GdkWindow     *window,
-			 GtkStateType   state_type,
-			 GtkShadowType  shadow_type,
-			 GdkRectangle  *area,
-			 GtkWidget     *widget,
-			 gchar         *detail,
-			 gint           x,
-			 gint           y,
-			 gint           width,
-			 gint           height,
-			 GtkOrientation orientation);
-   void (*draw_handle)  (GtkStyle      *style,
-			 GdkWindow     *window,
-			 GtkStateType   state_type,
-			 GtkShadowType  shadow_type,
-			 GdkRectangle  *area,
-			 GtkWidget     *widget,
-			 gchar         *detail,
-			 gint           x,
-			 gint           y,
-			 gint           width,
-			 gint           height,
-			 GtkOrientation orientation);
+  
+  void (*draw_hline)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x1,
+				 gint			 x2,
+				 gint			 y);
+  void (*draw_vline)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 y1,
+				 gint			 y2,
+				 gint			 x);
+  void (*draw_shadow)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height);
+  void (*draw_polygon)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 GdkPoint		*point,
+				 gint			 npoints,
+				 gboolean		 fill);
+  void (*draw_arrow)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 GtkArrowType		 arrow_type,
+				 gboolean		 fill,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height);
+  void (*draw_diamond)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height);
+  void (*draw_oval)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height);
+  void (*draw_string)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 const gchar		*string);
+  void (*draw_box)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height);
+  void (*draw_flat_box)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height);
+  void (*draw_check)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height);
+  void (*draw_option)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height);
+  void (*draw_cross)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height);
+  void (*draw_ramp)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 GtkArrowType		 arrow_type,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height);
+  void (*draw_tab)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height); 
+  void (*draw_shadow_gap)	(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height,
+				 GtkPositionType	 gap_side,
+				 gint			 gap_x,
+				 gint			 gap_width);
+  void (*draw_box_gap)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height,
+				 GtkPositionType	 gap_side,
+				 gint			 gap_x,
+				 gint			 gap_width);
+  void (*draw_extension)	(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height,
+				 GtkPositionType	 gap_side);
+  void (*draw_focus)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height);
+  void (*draw_slider)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height,
+				 GtkOrientation		 orientation);
+  void (*draw_handle)		(GtkStyle		*style,
+				 GdkWindow		*window,
+				 GtkStateType		 state_type,
+				 GtkShadowType		 shadow_type,
+				 GdkRectangle		*area,
+				 GtkWidget		*widget,
+				 gchar			*detail,
+				 gint			 x,
+				 gint			 y,
+				 gint			 width,
+				 gint			 height,
+				 GtkOrientation		 orientation);
 };
 
-GtkStyle* gtk_style_new		   (void);
-GtkStyle* gtk_style_copy	   (GtkStyle	 *style);
-GtkStyle* gtk_style_attach	   (GtkStyle	 *style,
-				    GdkWindow	 *window);
-void	  gtk_style_detach	   (GtkStyle	 *style);
-GtkStyle* gtk_style_ref		   (GtkStyle	 *style);
-void	  gtk_style_unref	   (GtkStyle	 *style);
-void	  gtk_style_set_background (GtkStyle	 *style,
-				    GdkWindow	 *window,
-				    GtkStateType  state_type);
-void      gtk_style_apply_default_pixmap(GtkStyle     *style,
-					 GdkWindow    *window, 
-					 GtkStateType  state_type, 
-					 GdkRectangle *area, 
-					 gint x, 
-					 gint y, 
-					 gint width, 
-					 gint height);
-      
+GtkStyle* gtk_style_new			     (void);
+GtkStyle* gtk_style_copy		     (GtkStyle	    *style);
+GtkStyle* gtk_style_attach		     (GtkStyle	    *style,
+					      GdkWindow	    *window);
+void	  gtk_style_detach		     (GtkStyle	   *style);
+GtkStyle* gtk_style_ref			     (GtkStyle	   *style);
+void	  gtk_style_unref		     (GtkStyle	   *style);
+void	  gtk_style_set_background	     (GtkStyle	   *style,
+					      GdkWindow	   *window,
+					      GtkStateType  state_type);
+void	  gtk_style_apply_default_background (GtkStyle	   *style,
+					      GdkWindow	   *window,
+					      gboolean	    set_bg,
+					      GtkStateType  state_type, 
+					      GdkRectangle *area, 
+					      gint	    x, 
+					      gint	    y, 
+					      gint	    width, 
+					      gint	    height);
+
 void gtk_draw_hline   (GtkStyle	     *style,
 		       GdkWindow     *window,
 		       GtkStateType   state_type,
@@ -422,105 +427,105 @@ void gtk_draw_flat_box (GtkStyle      *style,
 			GdkWindow     *window,
 			GtkStateType   state_type,
 			GtkShadowType  shadow_type,
-			gint           x,
-			gint           y,
-			gint           width,
-			gint           height);
-void gtk_draw_check   (GtkStyle      *style,
+			gint	       x,
+			gint	       y,
+			gint	       width,
+			gint	       height);
+void gtk_draw_check   (GtkStyle	     *style,
 		       GdkWindow     *window,
 		       GtkStateType   state_type,
 		       GtkShadowType  shadow_type,
-		       gint           x,
-		       gint           y,
-		       gint           width,
-		       gint           height);
-void gtk_draw_option  (GtkStyle      *style,
+		       gint	      x,
+		       gint	      y,
+		       gint	      width,
+		       gint	      height);
+void gtk_draw_option  (GtkStyle	     *style,
 		       GdkWindow     *window,
 		       GtkStateType   state_type,
 		       GtkShadowType  shadow_type,
-		       gint           x,
-		       gint           y,
-		       gint           width,
-		       gint           height);
-void gtk_draw_cross   (GtkStyle      *style,
+		       gint	      x,
+		       gint	      y,
+		       gint	      width,
+		       gint	      height);
+void gtk_draw_cross   (GtkStyle	     *style,
 		       GdkWindow     *window,
 		       GtkStateType   state_type,
 		       GtkShadowType  shadow_type,
-		       gint           x,
-		       gint           y,
-		       gint           width,
-		       gint           height);
-void gtk_draw_ramp    (GtkStyle      *style,
+		       gint	      x,
+		       gint	      y,
+		       gint	      width,
+		       gint	      height);
+void gtk_draw_ramp    (GtkStyle	     *style,
 		       GdkWindow     *window,
 		       GtkStateType   state_type,
 		       GtkShadowType  shadow_type,
 		       GtkArrowType   arrow_type,
-		       gint           x,
-		       gint           y,
-		       gint           width,
-		       gint           height);
-void gtk_draw_tab     (GtkStyle      *style,
+		       gint	      x,
+		       gint	      y,
+		       gint	      width,
+		       gint	      height);
+void gtk_draw_tab     (GtkStyle	     *style,
 		       GdkWindow     *window,
 		       GtkStateType   state_type,
 		       GtkShadowType  shadow_type,
-		       gint           x,
-		       gint           y,
-		       gint           width,
-		       gint           height);
-void gtk_draw_shadow_gap (GtkStyle       *style,
-			  GdkWindow      *window,
-			  GtkStateType    state_type,
-			  GtkShadowType   shadow_type,
-			  gint            x,
-			  gint            y,
-			  gint            width,
-			  gint            height,
+		       gint	      x,
+		       gint	      y,
+		       gint	      width,
+		       gint	      height);
+void gtk_draw_shadow_gap (GtkStyle	 *style,
+			  GdkWindow	 *window,
+			  GtkStateType	  state_type,
+			  GtkShadowType	  shadow_type,
+			  gint		  x,
+			  gint		  y,
+			  gint		  width,
+			  gint		  height,
 			  GtkPositionType gap_side,
-			  gint            gap_x,
-			  gint            gap_width);
-void gtk_draw_box_gap (GtkStyle       *style,
+			  gint		  gap_x,
+			  gint		  gap_width);
+void gtk_draw_box_gap (GtkStyle	      *style,
 		       GdkWindow      *window,
 		       GtkStateType    state_type,
 		       GtkShadowType   shadow_type,
-		       gint            x,
-		       gint            y,
-		       gint            width,
-		       gint            height,
+		       gint	       x,
+		       gint	       y,
+		       gint	       width,
+		       gint	       height,
 		       GtkPositionType gap_side,
-		       gint            gap_x,
-		       gint            gap_width);
-void gtk_draw_extension (GtkStyle       *style,
-			 GdkWindow      *window,
-			 GtkStateType    state_type,
-			 GtkShadowType   shadow_type,
-			 gint            x,
-			 gint            y,
-			 gint            width,
-			 gint            height,
+		       gint	       gap_x,
+		       gint	       gap_width);
+void gtk_draw_extension (GtkStyle	*style,
+			 GdkWindow	*window,
+			 GtkStateType	 state_type,
+			 GtkShadowType	 shadow_type,
+			 gint		 x,
+			 gint		 y,
+			 gint		 width,
+			 gint		 height,
 			 GtkPositionType gap_side);
-void gtk_draw_focus   (GtkStyle      *style,
+void gtk_draw_focus   (GtkStyle	     *style,
 		       GdkWindow     *window,
-		       gint           x,
-		       gint           y,
-		       gint           width,
-		       gint           height);
-void gtk_draw_slider  (GtkStyle      *style,
+		       gint	      x,
+		       gint	      y,
+		       gint	      width,
+		       gint	      height);
+void gtk_draw_slider  (GtkStyle	     *style,
 		       GdkWindow     *window,
 		       GtkStateType   state_type,
 		       GtkShadowType  shadow_type,
-		       gint           x,
-		       gint           y,
-		       gint           width,
-		       gint           height,
+		       gint	      x,
+		       gint	      y,
+		       gint	      width,
+		       gint	      height,
 		       GtkOrientation orientation);
-void gtk_draw_handle  (GtkStyle      *style,
+void gtk_draw_handle  (GtkStyle	     *style,
 		       GdkWindow     *window,
 		       GtkStateType   state_type,
 		       GtkShadowType  shadow_type,
-		       gint           x,
-		       gint           y,
-		       gint           width,
-		       gint           height,
+		       gint	      x,
+		       gint	      y,
+		       gint	      width,
+		       gint	      height,
 		       GtkOrientation orientation);
 
 void gtk_paint_hline   (GtkStyle      *style,
@@ -528,7 +533,7 @@ void gtk_paint_hline   (GtkStyle      *style,
 			GtkStateType   state_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
+			gchar	      *detail,
 			gint	       x1,
 			gint	       x2,
 			gint	       y);
@@ -537,7 +542,7 @@ void gtk_paint_vline   (GtkStyle      *style,
 			GtkStateType   state_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
+			gchar	      *detail,
 			gint	       y1,
 			gint	       y2,
 			gint	       x);
@@ -547,7 +552,7 @@ void gtk_paint_shadow  (GtkStyle     *style,
 			GtkShadowType shadow_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
+			gchar	      *detail,
 			gint	       x,
 			gint	       y,
 			gint	       width,
@@ -558,7 +563,7 @@ void gtk_paint_polygon (GtkStyle      *style,
 			GtkShadowType  shadow_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
+			gchar	      *detail,
 			GdkPoint      *points,
 			gint	       npoints,
 			gboolean       fill);
@@ -568,7 +573,7 @@ void gtk_paint_arrow   (GtkStyle      *style,
 			GtkShadowType  shadow_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
+			gchar	      *detail,
 			GtkArrowType   arrow_type,
 			gboolean       fill,
 			gint	       x,
@@ -581,7 +586,7 @@ void gtk_paint_diamond (GtkStyle      *style,
 			GtkShadowType  shadow_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
+			gchar	      *detail,
 			gint	       x,
 			gint	       y,
 			gint	       width,
@@ -592,7 +597,7 @@ void gtk_paint_oval    (GtkStyle      *style,
 			GtkShadowType  shadow_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
+			gchar	      *detail,
 			gint	       x,
 			gint	       y,
 			gint	       width,
@@ -602,7 +607,7 @@ void gtk_paint_string  (GtkStyle      *style,
 			GtkStateType   state_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
+			gchar	      *detail,
 			gint	       x,
 			gint	       y,
 			const gchar   *string);
@@ -612,138 +617,138 @@ void gtk_paint_box     (GtkStyle      *style,
 			GtkShadowType  shadow_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
+			gchar	      *detail,
 			gint	       x,
 			gint	       y,
 			gint	       width,
 			gint	       height);
 void gtk_paint_flat_box (GtkStyle      *style,
 			 GdkWindow     *window,
-			 GtkStateType   state_type,
-			 GtkShadowType  shadow_type,
+			 GtkStateType	state_type,
+			 GtkShadowType	shadow_type,
 			 GdkRectangle  *area,
 			 GtkWidget     *widget,
-			 gchar         *detail,
-			 gint           x,
-			 gint           y,
-			 gint           width,
-			 gint           height);
+			 gchar	       *detail,
+			 gint		x,
+			 gint		y,
+			 gint		width,
+			 gint		height);
 void gtk_paint_check   (GtkStyle      *style,
 			GdkWindow     *window,
 			GtkStateType   state_type,
 			GtkShadowType  shadow_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
-			gint           x,
-			gint           y,
-			gint           width,
-			gint           height);
+			gchar	      *detail,
+			gint	       x,
+			gint	       y,
+			gint	       width,
+			gint	       height);
 void gtk_paint_option  (GtkStyle      *style,
 			GdkWindow     *window,
 			GtkStateType   state_type,
 			GtkShadowType  shadow_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
-			gint           x,
-			gint           y,
-			gint           width,
-			gint           height);
+			gchar	      *detail,
+			gint	       x,
+			gint	       y,
+			gint	       width,
+			gint	       height);
 void gtk_paint_cross   (GtkStyle      *style,
 			GdkWindow     *window,
 			GtkStateType   state_type,
 			GtkShadowType  shadow_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
-			gint           x,
-			gint           y,
-			gint           width,
-			gint           height);
+			gchar	      *detail,
+			gint	       x,
+			gint	       y,
+			gint	       width,
+			gint	       height);
 void gtk_paint_ramp    (GtkStyle      *style,
 			GdkWindow     *window,
 			GtkStateType   state_type,
 			GtkShadowType  shadow_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
+			gchar	      *detail,
 			GtkArrowType   arrow_type,
-			gint           x,
-			gint           y,
-			gint           width,
-			gint           height);
+			gint	       x,
+			gint	       y,
+			gint	       width,
+			gint	       height);
 void gtk_paint_tab     (GtkStyle      *style,
 			GdkWindow     *window,
 			GtkStateType   state_type,
 			GtkShadowType  shadow_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
-			gint           x,
-			gint           y,
-			gint           width,
-			gint           height);
-void gtk_paint_shadow_gap (GtkStyle       *style,
-			   GdkWindow      *window,
-			   GtkStateType    state_type,
+			gchar	      *detail,
+			gint	       x,
+			gint	       y,
+			gint	       width,
+			gint	       height);
+void gtk_paint_shadow_gap (GtkStyle	  *style,
+			   GdkWindow	  *window,
+			   GtkStateType	   state_type,
 			   GtkShadowType   shadow_type,
-			   GdkRectangle   *area,
-			   GtkWidget      *widget,
-			   gchar          *detail,
-			   gint            x,
-			   gint            y,
-			   gint            width,
-			   gint            height,
+			   GdkRectangle	  *area,
+			   GtkWidget	  *widget,
+			   gchar	  *detail,
+			   gint		   x,
+			   gint		   y,
+			   gint		   width,
+			   gint		   height,
 			   GtkPositionType gap_side,
-			   gint            gap_x,
-			   gint            gap_width);
+			   gint		   gap_x,
+			   gint		   gap_width);
 void gtk_paint_box_gap (GtkStyle       *style,
 			GdkWindow      *window,
-			GtkStateType    state_type,
-			GtkShadowType   shadow_type,
+			GtkStateType	state_type,
+			GtkShadowType	shadow_type,
 			GdkRectangle   *area,
 			GtkWidget      *widget,
-			gchar          *detail,
-			gint            x,
-			gint            y,
-			gint            width,
-			gint            height,
+			gchar	       *detail,
+			gint		x,
+			gint		y,
+			gint		width,
+			gint		height,
 			GtkPositionType gap_side,
-			gint            gap_x,
-			gint            gap_width);
-void gtk_paint_extension (GtkStyle       *style,
-			  GdkWindow      *window,
-			  GtkStateType    state_type,
-			  GtkShadowType   shadow_type,
-			  GdkRectangle   *area,
-			  GtkWidget      *widget,
-			  gchar          *detail,
-			  gint            x,
-			  gint            y,
-			  gint            width,
-			  gint            height,
+			gint		gap_x,
+			gint		gap_width);
+void gtk_paint_extension (GtkStyle	 *style,
+			  GdkWindow	 *window,
+			  GtkStateType	  state_type,
+			  GtkShadowType	  shadow_type,
+			  GdkRectangle	 *area,
+			  GtkWidget	 *widget,
+			  gchar		 *detail,
+			  gint		  x,
+			  gint		  y,
+			  gint		  width,
+			  gint		  height,
 			  GtkPositionType gap_side);
 void gtk_paint_focus   (GtkStyle      *style,
 			GdkWindow     *window,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
-			gint           x,
-			gint           y,
-			gint           width,
-			gint           height);
+			gchar	      *detail,
+			gint	       x,
+			gint	       y,
+			gint	       width,
+			gint	       height);
 void gtk_paint_slider  (GtkStyle      *style,
 			GdkWindow     *window,
 			GtkStateType   state_type,
 			GtkShadowType  shadow_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
-			gint           x,
-			gint           y,
-			gint           width,
-			gint           height,
+			gchar	      *detail,
+			gint	       x,
+			gint	       y,
+			gint	       width,
+			gint	       height,
 			GtkOrientation orientation);
 void gtk_paint_handle  (GtkStyle      *style,
 			GdkWindow     *window,
@@ -751,13 +756,14 @@ void gtk_paint_handle  (GtkStyle      *style,
 			GtkShadowType  shadow_type,
 			GdkRectangle  *area,
 			GtkWidget     *widget,
-			gchar         *detail,
-			gint           x,
-			gint           y,
-			gint           width,
-			gint           height,
+			gchar	      *detail,
+			gint	       x,
+			gint	       y,
+			gint	       width,
+			gint	       height,
 			GtkOrientation orientation);
-      
+
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
