@@ -939,7 +939,10 @@ gtk_tree_size_allocate (GtkWidget     *widget,
 	  
 	  if (GTK_WIDGET_VISIBLE (child))
 	    {
-	      child_allocation.height = child->requisition.height;
+	      GtkRequisition child_requisition;
+	      gtk_widget_get_child_requisition (child, &child_requisition);
+	      
+	      child_allocation.height = child_requisition.height;
 	      
 	      gtk_widget_size_allocate (child, &child_allocation);
 	      
@@ -965,6 +968,7 @@ gtk_tree_size_request (GtkWidget      *widget,
   GtkTree *tree;
   GtkWidget *child, *subtree;
   GList *children;
+  GtkRequisition child_requisition;
   
   
   g_return_if_fail (widget != NULL);
@@ -983,20 +987,20 @@ gtk_tree_size_request (GtkWidget      *widget,
       
       if (GTK_WIDGET_VISIBLE (child))
 	{
-	  gtk_widget_size_request (child, &child->requisition);
+	  gtk_widget_size_request (child, &child_requisition);
 	  
-	  requisition->width = MAX (requisition->width, child->requisition.width);
-	  requisition->height += child->requisition.height;
+	  requisition->width = MAX (requisition->width, child_requisition.width);
+	  requisition->height += child_requisition.height;
 	  
 	  if((subtree = GTK_TREE_ITEM(child)->subtree) &&
 	     GTK_WIDGET_VISIBLE (subtree))
 	    {
-	      gtk_widget_size_request (subtree, &subtree->requisition);
+	      gtk_widget_size_request (subtree, &child_requisition);
 	      
 	      requisition->width = MAX (requisition->width, 
-					subtree->requisition.width);
+					child_requisition.width);
 	      
-	      requisition->height += subtree->requisition.height;
+	      requisition->height += child_requisition.height;
 	    }
 	}
     }
