@@ -103,8 +103,6 @@ static void gtk_window_paint              (GtkWidget         *widget,
 					   GdkRectangle      *area);
 static gint gtk_window_expose             (GtkWidget         *widget,
 				           GdkEventExpose    *event);
-static void gtk_window_style_set          (GtkWidget         *widget,
-				           GtkStyle          *previous_style);
 static void gtk_window_unset_transient_for         (GtkWindow  *window);
 static void gtk_window_transient_parent_realized   (GtkWidget  *parent,
 						    GtkWidget  *window);
@@ -171,7 +169,7 @@ gtk_window_class_init (GtkWindowClass *klass)
                     GTK_SIGNAL_OFFSET (GtkWindowClass, set_focus),
                     gtk_marshal_NONE__POINTER,
 		    GTK_TYPE_NONE, 1,
-                    GTK_TYPE_POINTER);
+                    GTK_TYPE_WIDGET);
 
   gtk_object_class_add_signals (object_class, window_signals, LAST_SIGNAL);
 
@@ -196,7 +194,6 @@ gtk_window_class_init (GtkWindowClass *klass)
   widget_class->focus_in_event = gtk_window_focus_in_event;
   widget_class->focus_out_event = gtk_window_focus_out_event;
   widget_class->client_event = gtk_window_client_event;
-  widget_class->style_set = gtk_window_style_set;
 
   widget_class->draw = gtk_window_draw;
   widget_class->expose_event = gtk_window_expose;
@@ -361,7 +358,8 @@ gtk_window_set_focus (GtkWindow *window,
       g_return_if_fail (GTK_WIDGET_CAN_FOCUS (focus));
     }
 
-  if (window->focus_widget != focus)
+  if ((window->focus_widget != focus) ||
+      (focus && !GTK_WIDGET_HAS_FOCUS (focus)))
     gtk_signal_emit (GTK_OBJECT (window), window_signals[SET_FOCUS], focus);
 }
 
@@ -890,10 +888,12 @@ gtk_window_size_request (GtkWidget      *widget,
 
   if (bin->child && GTK_WIDGET_VISIBLE (bin->child))
     {
-      gtk_widget_size_request (bin->child, &bin->child->requisition);
+      GtkRequisition child_requisition;
+      
+      gtk_widget_size_request (bin->child, &child_requisition);
 
-      requisition->width += bin->child->requisition.width;
-      requisition->height += bin->child->requisition.height;
+      requisition->width += child_requisition.width;
+      requisition->height += child_requisition.height;
     }
   else
     {
@@ -1320,7 +1320,7 @@ gtk_window_move_resize (GtkWindow *window)
 
   if (info && info->width > 0)
     {
-      size_changed = size_changed || (width != info->width);
+      size_changed = size_changed || (width != info->last_width);
       info->last_width = width;
       new_width = info->width;
     }
@@ -1332,7 +1332,7 @@ gtk_window_move_resize (GtkWindow *window)
 
   if (info && info->height > 0)
     {
-      size_changed = size_changed || (height != info->height);
+      size_changed = size_changed || (height != info->last_height);
       info->last_height = height;
       new_height = info->height;
     }
@@ -1693,25 +1693,3 @@ gtk_window_draw (GtkWidget    *widget,
   if (GTK_WIDGET_CLASS (parent_class)->draw)
     (* GTK_WIDGET_CLASS (parent_class)->draw) (widget, area);
 }
-
-static void
-gtk_window_style_set (GtkWidget *widget,
-		      GtkStyle  *previous_style)
-{
-   GdkRectangle area;
-   
-   if (GTK_WIDGET_REALIZED (widget) &&
-       !GTK_WIDGET_NO_WINDOW (widget))
-     {
-	gtk_style_set_background (widget->style, widget->window, widget->state);
-
-	area.x = 0;
-	area.y = 0;
-	area.width = widget->allocation.width;
-	area.height = widget->allocation.height;
-	gtk_window_draw(widget, &area);
-
-	if (GTK_WIDGET_DRAWABLE (widget))
-	  gdk_window_clear (widget->window);
-     }
-}
